@@ -32,6 +32,7 @@ in this Software without prior written authorization from The Open Group.
 #include <stdio.h>
 #include "Cr.h"
 #include "ImUtil.h"
+#include "reallocarray.h"
 
 #if defined(__STDC__) && ((defined(sun) && defined(SVR4)) || defined(WIN32))
 #define RConst /**/
@@ -118,8 +119,8 @@ static unsigned char const _reverse_nibs[0x100] = {
 
 int
 _XReverse_Bytes(
-    register unsigned char *bpt,
-    register int nb)
+    unsigned char *bpt,
+    int nb)
 {
     do {
 	*bpt = _reverse_byte[*bpt];
@@ -602,7 +603,7 @@ static int const HalfOrderWord[12] = {
 
 #define UnGetReq(name)\
     dpy->bufptr -= SIZEOF(x##name##Req);\
-    dpy->request--
+    X_DPY_REQUEST_DECREMENT(dpy)
 
 static void
 SendXYImage(
@@ -740,8 +741,7 @@ SendXYImage(
 		    bytes_per_src, bytes_per_line,
 		    bytes_per_dest, req->height, half_order);
 
-    if (extra)
-	Xfree(extra);
+    Xfree(extra);
 
     if (buf == dpy->bufptr)
 	dpy->bufptr += length;
@@ -772,7 +772,7 @@ SendZImage(
 	  (req_yoffset * image->bytes_per_line) +
 	  ((req_xoffset * image->bits_per_pixel) >> 3);
     if ((image->bits_per_pixel == 4) && ((unsigned int) req_xoffset & 0x01)) {
-	if (! (shifted_src = Xmalloc(req->height * image->bytes_per_line))) {
+	if (! (shifted_src = Xmallocarray(req->height, image->bytes_per_line))) {
 	    UnGetReq(PutImage);
 	    return;
 	}
@@ -793,8 +793,7 @@ SendZImage(
 	((req_xoffset == 0) ||
 	 ((req_yoffset + req->height) < (unsigned)image->height))) {
 	Data(dpy, (char *)src, length);
-	if (shifted_src)
-	    Xfree(shifted_src);
+	Xfree(shifted_src);
 	return;
     }
 
@@ -804,7 +803,7 @@ SendZImage(
     else
 	if ((dest = (unsigned char *)
 	     _XAllocScratch(dpy, length)) == NULL) {
-	    if (shifted_src) Xfree(shifted_src);
+	    Xfree(shifted_src);
 	    UnGetReq(PutImage);
 	    return;
 	}
@@ -831,8 +830,7 @@ SendZImage(
     else
 	_XSend(dpy, (char *)dest, length);
 
-    if (shifted_src)
-        Xfree(shifted_src);
+    Xfree(shifted_src);
 }
 
 static void
@@ -994,7 +992,7 @@ XPutImage (
 	    img.bits_per_pixel = dest_bits_per_pixel;
 	    img.bytes_per_line = ROUNDUP((dest_bits_per_pixel * width),
 					 dest_scanline_pad) >> 3;
-	    img.data = Xmalloc(img.bytes_per_line * height);
+	    img.data = Xmallocarray(height, img.bytes_per_line);
 	    if (img.data == NULL)
 		return 0;
 	    _XInitImageFuncPtrs(&img);
