@@ -30,6 +30,7 @@
 #include "XlcPubI.h"
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
+#include "reallocarray.h"
 
 static XPointer *
 alloc_list(
@@ -40,11 +41,11 @@ alloc_list(
     if (is_wide_char) {
 	wchar_t **wstr_list;
 
-	wstr_list = Xmalloc(count * sizeof(wchar_t *));
+	wstr_list = Xmallocarray(count, sizeof(wchar_t *));
 	if (wstr_list == NULL)
 	    return (XPointer *) NULL;
 
-	*wstr_list = Xmalloc(nitems * sizeof(wchar_t));
+	*wstr_list = Xmallocarray(nitems, sizeof(wchar_t));
 	if (*wstr_list == NULL) {
 	    Xfree(wstr_list);
 	    return (XPointer *) NULL;
@@ -54,7 +55,7 @@ alloc_list(
     } else {
 	char **str_list;
 
-	str_list = Xmalloc(count * sizeof(char *));
+	str_list = Xmallocarray(count, sizeof(char *));
 	if (str_list == NULL)
 	    return (XPointer *) NULL;
 
@@ -99,7 +100,7 @@ copy_list(
 	for (str = *str_list; count > 0; count--, str_list++) {
 	    strcpy(str, mb_text);
 	    *str_list = str;
-	    length = strlen(str) + 1;
+	    length = (int) strlen(str) + 1;
 	    str += length;
 	    mb_text += length;
 	}
@@ -149,7 +150,7 @@ _XTextPropertyToTextList(
 	return XConverterNotFound;
 
     if (is_wide_char) {
-	buf_len = (text_prop->nitems + 1) * sizeof(wchar_t);;
+	buf_len = (text_prop->nitems + 1) * sizeof(wchar_t);
     } else {
 	if (strcmp(to_type, XlcNUtf8String) == 0)
 	    buf_len = text_prop->nitems * 6 + 1;
@@ -185,7 +186,7 @@ _XTextPropertyToTextList(
 
             if (do_strcpy) {
             	len = min(from_left, to_left);
-                strncpy(to, from, len);
+                strncpy(to, from, (size_t) len);
                 from += len;
                 to += len;
                 from_left -= len;
@@ -283,8 +284,7 @@ _XwcFreeStringList(
     wchar_t **list)
 {
     if (list) {
-        if (*list)
-	     Xfree(*list);
+        Xfree(*list);
         Xfree(list);
     }
 }
